:py:mod:`piel.models.physical.electronic.via_stack`
===================================================

.. py:module:: piel.models.physical.electronic.via_stack


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   piel.models.physical.electronic.via_stack.ViaStackParameters



Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.electronic.via_stack.via_stack



.. py:class:: ViaStackParameters



.. py:function:: via_stack(params: ViaStackParameters) -> hdl21.Module

   Implements a `hdl21` taper resistor class. We need to include the mapping ports as we expect our gdsfactory component to be with the instance of the model.
